sorl-thumbnail
==============

Thumbnails for Django. Totally rewritten.

Features at a glance
--------------------
- Storage support
- Pluggable Engine support (PIL, pgmagick)
- Pluggable Key Value Store support (redis, cached db)
- Pluggable Backend support
- Admin integration with possibility to delete
- Dummy generation
- Flexible, simple syntax, generates no html
- ImageField for model that deletes thumbnails
- CSS style cropping options
- Margin calculation for vertical positioning

Read more in `the documentation (latest version) <http://thumbnail.sorl.net/>`_

